.actor-header__avatar {
    width: 50px;
    height: 50px;
    border-radius: 30%;
    margin-right: 10px;
}

.actor-header {
    display:flex;
    
}

.actor-header a{
    text-decoration: none;
}

.actor-header__name {
    padding-top: 5px;
    font-weight: bold;
}

.actor-header__identifier {
    padding-top: 5px;
    font-family: monospace;
}